Wrapper for datasets about Energy Communities providing the ability to immediately
extract key stats such as the breakdown of covered energy (self-coverage, trading over market,
and discharged from community battery) and automatically generate a report. The market is implicit and computed optimally at each timestep using a max-flow algorithm.

The functionality is provided by the *ECDataset* class. For its construction, provide it with two 2D Pandas DataFrames *production* and *consumption*, where *production*[i][j] is the production of community member j at timestep i and consumption[i][j] is the consumption of community member j at timestep i. Also, pass the timestep used in the dataset as a fraction/multiple of one hour as a parameter.

## Installation
To use in your own projects, pip install in a console first:

``` bash
pip install ec-data-analysis
```

Then, simply import the ECDataset class:

``` python
from ec_data_analysis import ECDataset
```

## Example Usage
Example usage is provided in the main.py file:
```python
from ec_data_analysis import ECDataset

...

def main() -> None:
    data: pd.DataFrame = pd.read_excel("data/EC_EV_dataset.xlsx", sheet_name=None)
    production: pd.DataFrame = getSheet("PV", data)
    consumption: pd.DataFrame = getSheet("Load", data)

    ecData: ECDataset = ECDataset(production, consumption, 0.25)
    ecData.createReport()
```

The example report generated by this is in out/report.pdf based on the example dataset data/EC_EV_dataset.xlsx.

## Develop
In case want to play with the code yourself to add more plots or metrics, the project is provided with a formating tool (black) and typechecker (mypy). The code is almost fully annotated with type hints, and the provided Makefile typechecks with:

```bash
Make typecheck
```

To format, typecheck and then run main.py, run:
```bash
Make all
```

Or to simply run main.py:
```bash
Make run
```
